==> 0.10.0.tar.gz: lib/src/menu_widget.dart <==
import 'package:demoflu/src/demoflu_settings.dart';
import 'package:demoflu/src/menu_item.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class MenuWidget extends StatelessWidget {
  MenuWidget({required this.settings, required this.menuItems});

  final DemoFluSettings settings;
  final List<MenuItem> menuItems;

  @override
  Widget build(BuildContext context) {
    List<Widget> children = [];
    for (MenuItem menuItem in menuItems) {
      children.add(_MenuItemWidget(
          settings: settings,
          selected: settings.currentMenuItem == menuItem,
          menuItem: menuItem));
    }
    return Container(
        child: SingleChildScrollView(
            controller: ScrollController(),
            child: IntrinsicWidth(
                child: Column(
                    children: children,
                    crossAxisAlignment: CrossAxisAlignment.stretch))),
        decoration: BoxDecoration(
            color: Colors.blueGrey[900],
            border: Border(
                right: BorderSide(color: Colors.blueGrey[900]!, width: 2))));
  }
}

class _MenuItemWidget extends StatefulWidget {
  const _MenuItemWidget(
      {required this.settings, required this.selected, required this.menuItem});

  final DemoFluSettings settings;
  final bool selected;
  final MenuItem menuItem;

  @override
  State<StatefulWidget> createState() => _MenuItemWidgetState();
}

class _MenuItemWidgetState extends State<_MenuItemWidget> {
  bool hover = false;

  @override
  Widget build(BuildContext context) {
    double left = 8;
    if (widget.menuItem.indentation > 1) {
      left = left * widget.menuItem.indentation;
    }
    Widget text = Padding(
        child: Text(widget.menuItem.name,
            style: TextStyle(color: _textColor(), fontStyle: _fontStyle())),
        padding: EdgeInsets.fromLTRB(left, 8, 8, 8));

    if (widget.menuItem.builder == null) {
      return text;
    }

    return MouseRegion(
        onEnter: _onEnter,
        onExit: _onExit,
        child: Container(
            color: _background(), child: InkWell(child: text, onTap: _onTap)));
  }

  FontStyle _fontStyle() {
    if (widget.menuItem.italic) {
      return FontStyle.italic;
    }
    return FontStyle.normal;
  }

  Color _textColor() {
    if (widget.selected) {
      return Colors.black;
    }
    return Colors.white;
  }

  Color _background() {
    if (widget.selected) {
      return Colors.blueGrey[100]!;
    } else if (hover) {
      return Colors.blueGrey[700]!;
    }
    return Colors.transparent;
  }

  void _onEnter(PointerEnterEvent event) {
    setState(() {
      hover = true;
    });
  }

  void _onExit(PointerExitEvent event) {
    setState(() {
      hover = false;
    });
  }

  _onTap() {
    widget.settings.updateCurrentExample(widget.menuItem);
  }
}

==> 0.15.0.tar.gz: lib/src/menu_widget.dart <==
import 'package:demoflu/src/demoflu_settings.dart';
import 'package:demoflu/src/demo_menu_item.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class MenuWidget extends StatelessWidget {
  MenuWidget({required this.settings, required this.menuItems});

  final DemoFluSettings settings;
  final List<DemoMenuItem> menuItems;

  @override
  Widget build(BuildContext context) {
    List<Widget> children = [];
    for (DemoMenuItem menuItem in menuItems) {
      children.add(_MenuItemWidget(
          settings: settings,
          selected: settings.currentMenuItem == menuItem,
          menuItem: menuItem));
    }
    return Container(
        child: SingleChildScrollView(
            controller: ScrollController(),
            child: IntrinsicWidth(
                child: Column(
                    children: children,
                    crossAxisAlignment: CrossAxisAlignment.stretch))),
        decoration: BoxDecoration(
            color: Colors.blueGrey[900],
            border: Border(
                right: BorderSide(color: Colors.blueGrey[900]!, width: 2))));
  }
}

class _MenuItemWidget extends StatefulWidget {
  const _MenuItemWidget(
      {required this.settings, required this.selected, required this.menuItem});

  final DemoFluSettings settings;
  final bool selected;
  final DemoMenuItem menuItem;

  @override
  State<StatefulWidget> createState() => _MenuItemWidgetState();
}

class _MenuItemWidgetState extends State<_MenuItemWidget> {
  bool hover = false;

  @override
  Widget build(BuildContext context) {
    double left = 8;
    if (widget.menuItem.indentation > 1) {
      left = left * widget.menuItem.indentation;
    }
    Widget text = Padding(
        child: Text(widget.menuItem.name,
            style: TextStyle(color: _textColor(), fontStyle: _fontStyle())),
        padding: EdgeInsets.fromLTRB(left, 8, 8, 8));

    if (widget.menuItem.builder == null) {
      return text;
    }

    return MouseRegion(
        onEnter: _onEnter,
        onExit: _onExit,
        child: Container(
            color: _background(), child: InkWell(child: text, onTap: _onTap)));
  }

  FontStyle _fontStyle() {
    if (widget.menuItem.italic) {
      return FontStyle.italic;
    }
    return FontStyle.normal;
  }

  Color _textColor() {
    if (widget.selected) {
      return Colors.black;
    }
    return Colors.white;
  }

  Color _background() {
    if (widget.selected) {
      return Colors.blueGrey[100]!;
    } else if (hover) {
      return Colors.blueGrey[700]!;
    }
    return Colors.transparent;
  }

  void _onEnter(PointerEnterEvent event) {
    setState(() {
      hover = true;
    });
  }

  void _onExit(PointerExitEvent event) {
    setState(() {
      hover = false;
    });
  }

  _onTap() {
    widget.settings.updateCurrentExample(widget.menuItem);
  }
}
